SOAK DISTRIBUTION
*
* This file contains the default MOBILE6 values for the distribution of
* engine starts by time since last engine running (soak time) for each
* hour of the day, separately for weekdays and weekends.
*
* The data in the array is read as a single block of numbers.  There are
* 24 values for each hour of the day.  There are 70 soak time groupings.
* Each grouping contains the fraction of all engine starts in that hour
* which have occurred after a soak time within the specified time range.
* There are two sets of these values, one for a typical weekday and one
* set for a typical weekend day.  This is a total of 3360 values.  The
* 70 soak time groupings (with the nominal time designation and the
* associated time intervals) are:
*
*       Nominal                          Nominal
* Soak  Soak      Minutes          Soak  Soak      Minutes
* Index Minutes   Range            Index Minutes   Range
* ----- -------   --------         ----- -------   ----------
*   1      1      >0 - 1            36     42      >40 - 42
*   2      2      >1 - 2            37     44      >42 - 44
*   3      3      >2 - 3            38     46      >44 - 46
*   4      4      >3 - 4            39     48      >46 - 48
*   5      5      >4 - 5            40     50      >48 - 50
*   6      6      >5 - 6            41     52      >50 - 52
*   7      7      >6 - 7            42     54      >52 - 54
*   8      8      >7 - 8            43     56      >54 - 56
*   9      9      >8 - 9            44     58      >56 - 58
*  10     10      >9 - 10           45     60      >58 - 60
*  11     11      >10 - 11          46     90      >60 - 90
*  12     12      >11 - 12          47    120      >90 - 120
*  13     13      >12 - 13          48    150      >120 - 150
*  14     14      >13 - 14          49    180      >150 - 180
*  15     15      >14 - 15          50    210      >180 - 210
*  16     16      >15 - 16          51    240      >210 - 240
*  17     17      >16 - 17          52    270      >240 - 270
*  18     18      >17 - 18          53    300      >270 - 300
*  19     19      >18 - 19          54    330      >300 - 330
*  20     20      >19 - 20          55    360      >330 - 360
*  21     21      >20 - 21          56    390      >360 - 390
*  22     22      >21 - 22          57    420      >390 - 420
*  23     23      >22 - 23          58    450      >420 - 450
*  24     24      >23 - 24          59    480      >450 - 480
*  25     25      >24 - 25          60    510      >480 - 510
*  26     26      >25 - 26          61    540      >510 - 540
*  27     27      >26 - 27          62    570      >540 - 570
*  28     28      >27 - 28          63    600      >570 - 600
*  29     29      >28 - 29          64    630      >600 - 630
*  30     30      >29 - 30          65    660      >630 - 660
*  31     32      >30 - 32          66    690      >660 - 690
*  32     34      >32 - 34          67    720      >690 - 720
*  33     36      >34 - 36          68    720      >720
*  34     38      >36 - 38          69    0.01     Restart
*  35     40      >38 - 40          70    0.0      Not Used
*
* The hours of the day are done in the following order:
*
*  Hour
* Index      Time       Description
* -----     ------      ------------------------------
*   1       6 a.m.       6 a.m. through 6:59 a.m.
*   2       7 a.m.       7 a.m. through 7:59 a.m.
*   3       8 a.m.       8 a.m. through 8:59 a.m.
*   4       9 a.m.       9 a.m. through 9:59 a.m.
*   5      10 a.m.      10 a.m. through 10:59 a.m.
*   6      11 a.m.      11 a.m. through 11:59 a.m.
*   7      12 Noon      12 Noon through 12:59 p.m.
*   8       1 p.m.       1 p.m. through 1:59 p.m.
*   9       2 p.m.       2 p.m. through 2:59 p.m.
*  10       3 p.m.       3 p.m. through 3:59 p.m.
*  11       4 p.m.       4 p.m. through 4:59 p.m.
*  12       5 p.m.       5 p.m. through 5:59 p.m.
*  13       6 p.m.       6 p.m. through 6:59 p.m.
*  14       7 p.m.       7 p.m. through 7:59 p.m.
*  15       8 p.m.       8 p.m. through 8:59 p.m.
*  16       9 p.m.       9 p.m. through 9:59 p.m.
*  17      10 p.m.      10 p.m. through 10:59 p.m.
*  18      11 p.m.      11 p.m. through 11:59 p.m.
*  19      12 Midnight  12 Midnight through 12:59 a.m.
*  20       1 a.m.       1 a.m. through 1:59 a.m.
*  21       2 a.m.       2 a.m. through 2:59 a.m.
*  22       3 a.m.       3 a.m. through 3:59 a.m.
*  23       4 a.m.       4 a.m. through 4:59 a.m.
*  24       5 a.m.       5 a.m. through 5:59 a.m.
*
* All 3360 values are read "free format," meaning any number may appear
* in any row with as many characters as needed (including a decimal) as
* long as each value is separated by a space.  However, no comment lines
* (such as these) may occur anywhere once the numbers begin.  All of
* the values are read together as a block.
*
* The numbers must be listed in the following order:
*
*     - 24 values (hours 1 - 24) for soak index 1, weekday,
*     - 24 values (hours 1 - 24) for soak index 2, weekday,
*     ..... (etc.)
*     - 24 values (hours 1 - 24) for soak index 70, weekday,
*     - 24 values (hours 1 - 24) for soak index 1, weekend,
*     - 24 values (hours 1 - 24) for soak index 2, weekend,
*     ..... (etc.)
*     - 24 values (hours 1 - 24) for soak index 70, weekend,
*
0.038759690 0.025139665 0.044270836 0.046822742 0.061728396 
0.018691588 0.049618319 0.038709678 0.048732944 0.038394414 
0.044198893 0.036144577 0.033766232 0.033985581 0.033985581 
0.033985581 0.033985581 0.033985581 0.033985581 0.033985581 
0.033985581 0.033985581 0.033985581 0.033985581 
0.031007752 0.061452512 0.041666664 0.050167222 0.061728396 
0.046728972 0.055343509 0.049462367 0.048732944 0.059336826 
0.046040516 0.060240965 0.036363635 0.037075181 0.037075181 
0.037075181 0.037075181 0.037075181 0.037075181 0.037075181 
0.037075181 0.037075181 0.037075181 0.037075181 
0.023255814 0.033519555 0.031250000 0.053511705 0.040123459 
0.049065422 0.049618319 0.038709678 0.046783622 0.047120418 
0.044198893 0.066265061 0.038961038 0.028836250 0.028836250 
0.028836250 0.028836250 0.028836250 0.028836250 0.028836250 
0.028836250 0.028836250 0.028836250 0.028836250 
0.015503876 0.030726256 0.023437500 0.026755853 0.040123459 
0.046728972 0.047709923 0.040860213 0.019493178 0.034904014 
0.034990791 0.036144577 0.031168830 0.022657054 0.022657054 
0.022657054 0.022657054 0.022657054 0.022657054 0.022657054 
0.022657054 0.022657054 0.022657054 0.022657054 
0.007751938 0.005586592 0.023437500 0.020066891 0.021604938 
0.032710280 0.024809159 0.032258064 0.046783622 0.036649216 
0.040515650 0.020080321 0.033766232 0.017507724 0.017507724 
0.017507724 0.017507724 0.017507724 0.017507724 0.017507724 
0.017507724 0.017507724 0.017507724 0.017507724 
0.007751938 0.008379888 0.033854168 0.023411371 0.033950616 
0.037383176 0.038167939 0.032258064 0.027290449 0.040139619 
0.023941068 0.022088354 0.038961038 0.015447992 0.015447992 
0.015447992 0.015447992 0.015447992 0.015447992 0.015447992 
0.015447992 0.015447992 0.015447992 0.015447992 
0.000000000 0.011173184 0.020833332 0.010033445 0.012345679 
0.032710280 0.020992365 0.021505374 0.031189084 0.026178010 
0.018416205 0.024096387 0.023376621 0.016477859 0.016477859 
0.016477859 0.016477859 0.016477859 0.016477859 0.016477859 
0.016477859 0.016477859 0.016477859 0.016477859 
0.015503876 0.005586592 0.013020832 0.013377926 0.006172840 
0.011682243 0.020992365 0.025806451 0.025341131 0.026178010 
0.020257825 0.018072288 0.031168830 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 
0.007751938 0.002793296 0.002604167 0.006688963 0.009259259 
0.030373834 0.017175574 0.021505374 0.023391811 0.017452007 
0.020257825 0.014056224 0.002597403 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 
0.007751938 0.005586592 0.026041668 0.016722409 0.018518519 
0.009345794 0.009541985 0.012903226 0.019493178 0.024432810 
0.014732965 0.010040160 0.018181818 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 
0.007751938 0.002793296 0.018229168 0.020066891 0.024691358 
0.018691588 0.019083969 0.025806451 0.017543860 0.015706806 
0.022099447 0.014056224 0.010389610 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 
0.000000000 0.005586592 0.013020832 0.026755853 0.012345679 
0.032710280 0.019083969 0.019354839 0.013645224 0.015706806 
0.009208103 0.010040160 0.020779220 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 
0.000000000 0.005586592 0.015625000 0.010033445 0.003086420 
0.009345794 0.005725191 0.012903226 0.017543860 0.012216405 
0.012891344 0.012048193 0.015584417 0.005149330 0.005149330 
0.005149330 0.005149330 0.005149330 0.005149330 0.005149330 
0.005149330 0.005149330 0.005149330 0.005149330 
0.000000000 0.005586592 0.010416668 0.006688963 0.012345679 
0.007009346 0.011450383 0.015053763 0.009746589 0.006980803 
0.005524862 0.010040160 0.007792208 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 
0.000000000 0.005586592 0.010416668 0.010033445 0.009259259 
0.011682243 0.015267176 0.015053763 0.003898635 0.010471204 
0.014732965 0.014056224 0.012987013 0.013388259 0.013388259 
0.013388259 0.013388259 0.013388259 0.013388259 0.013388259 
0.013388259 0.013388259 0.013388259 0.013388259 
0.000000000 0.000000000 0.005208333 0.013377926 0.006172840 
0.009345794 0.009541985 0.008602152 0.001949318 0.010471204 
0.009208103 0.008032129 0.018181818 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 
0.007751938 0.002793296 0.015625000 0.010033445 0.012345679 
0.014018692 0.011450383 0.008602152 0.013645224 0.003490401 
0.003683241 0.004016064 0.010389610 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 
0.004672897 0.007633588 0.010752687 0.015594542 0.012216405 
0.000000000 0.008379888 0.010416668 0.003344482 0.012345679 
0.011049723 0.008032129 0.000000000 0.011328527 0.011328527 
0.011328527 0.011328527 0.011328527 0.011328527 0.011328527 
0.011328527 0.011328527 0.011328527 0.011328527 
0.000000000 0.000000000 0.010416668 0.010033445 0.006172840 
0.007009346 0.019083969 0.017204301 0.003898635 0.006980803 
0.011049723 0.014056224 0.010389610 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 
0.000000000 0.005586592 0.013020832 0.013377926 0.015432099 
0.007009346 0.013358779 0.002150538 0.007797271 0.010471204 
0.011049723 0.006024096 0.002597403 0.010298661 0.010298661 
0.010298661 0.010298661 0.010298661 0.010298661 0.010298661 
0.010298661 0.010298661 0.010298661 0.010298661 
0.000000000 0.008379888 0.000000000 0.003344482 0.012345679 
0.011682243 0.009541985 0.012903226 0.003898635 0.008726004 
0.009208103 0.006024096 0.007792208 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 
0.000000000 0.000000000 0.007812500 0.010033445 0.006172840 
0.004672897 0.005725191 0.021505374 0.011695906 0.010471204 
0.005524862 0.004016064 0.010389610 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 
0.000000000 0.000000000 0.000000000 0.000000000 0.015432099 
0.014018692 0.007633588 0.002150538 0.007797271 0.010471204 
0.007366483 0.012048193 0.012987013 0.011328527 0.011328527 
0.011328527 0.011328527 0.011328527 0.011328527 0.011328527 
0.011328527 0.011328527 0.011328527 0.011328527 
0.000000000 0.000000000 0.007812500 0.023411371 0.006172840 
0.004672897 0.005725191 0.015053763 0.007797271 0.006980803 
0.011049723 0.012048193 0.002597403 0.008238929 0.008238929 
0.008238929 0.008238929 0.008238929 0.008238929 0.008238929 
0.008238929 0.008238929 0.008238929 0.008238929 
0.000000000 0.000000000 0.002604167 0.010033445 0.000000000 
0.004672897 0.003816794 0.012903226 0.005847953 0.006980803 
0.005524862 0.002008032 0.002597403 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 
0.000000000 0.000000000 0.005208333 0.006688963 0.009259259 
0.009345794 0.011450383 0.008602152 0.007797271 0.001745201 
0.009208103 0.008032129 0.002597403 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 
0.000000000 0.000000000 0.007812500 0.003344482 0.000000000 
0.004672897 0.005725191 0.002150538 0.011695906 0.003490401 
0.007366483 0.012048193 0.007792208 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 
0.000000000 0.002793296 0.002604167 0.003344482 0.000000000 
0.011682243 0.001908397 0.010752687 0.007797271 0.005235602 
0.005524862 0.008032129 0.005194805 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 
0.000000000 0.002793296 0.000000000 0.003344482 0.009259259 
0.002336449 0.005725191 0.008602152 0.001949318 0.003490401 
0.003683241 0.004016064 0.015584417 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 
0.000000000 0.000000000 0.002604167 0.010033445 0.003086420 
0.004672897 0.003816794 0.006451613 0.005847953 0.005235602 
0.012891344 0.002008032 0.005194805 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 
0.000000000 0.000000000 0.007812500 0.013377926 0.009259259 
0.016355140 0.011450383 0.006451613 0.013645224 0.012216405 
0.011049723 0.012048193 0.005194805 0.011328527 0.011328527 
0.011328527 0.011328527 0.011328527 0.011328527 0.011328527 
0.011328527 0.011328527 0.011328527 0.011328527 
0.007751938 0.005586592 0.007812500 0.003344482 0.006172840 
0.014018692 0.020992365 0.017204301 0.013645224 0.006980803 
0.007366483 0.016064256 0.007792208 0.008238929 0.008238929 
0.008238929 0.008238929 0.008238929 0.008238929 0.008238929 
0.008238929 0.008238929 0.008238929 0.008238929 
0.000000000 0.000000000 0.002604167 0.000000000 0.012345679 
0.011682243 0.013358779 0.008602152 0.017543860 0.003490401 
0.012891344 0.008032129 0.007792208 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 
0.000000000 0.002793296 0.010416668 0.006688963 0.003086420 
0.004672897 0.005725191 0.010752687 0.009746589 0.012216405 
0.005524862 0.008032129 0.007792208 0.005149330 0.005149330 
0.005149330 0.005149330 0.005149330 0.005149330 0.005149330 
0.005149330 0.005149330 0.005149330 0.005149330 
0.000000000 0.000000000 0.005208333 0.010033445 0.012345679 
0.014018692 0.007633588 0.006451613 0.009746589 0.013961606 
0.009208103 0.008032129 0.007792208 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 
0.000000000 0.000000000 0.000000000 0.013377926 0.009259259 
0.004672897 0.011450383 0.010752687 0.007797271 0.005235602 
0.007366483 0.010040160 0.007792208 0.002059732 0.002059732 
0.002059732 0.002059732 0.002059732 0.002059732 0.002059732 
0.002059732 0.002059732 0.002059732 0.002059732 
0.000000000 0.002793296 0.005208333 0.006688963 0.012345679 
0.014018692 0.009541985 0.006451613 0.005847953 0.010471204 
0.003683241 0.008032129 0.012987013 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 
0.000000000 0.000000000 0.000000000 0.000000000 0.006172840 
0.004672897 0.009541985 0.010752687 0.007797271 0.012216405 
0.007366483 0.004016064 0.005194805 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 
0.000000000 0.005586592 0.005208333 0.020066891 0.006172840 
0.009345794 0.003816794 0.004301075 0.017543860 0.003490401 
0.007366483 0.006024096 0.005194805 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 
0.000000000 0.002793296 0.007812500 0.000000000 0.018518519 
0.007009346 0.003816794 0.006451613 0.000000000 0.001745201 
0.009208103 0.006024096 0.005194805 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 
0.000000000 0.002793296 0.000000000 0.003344482 0.009259259 
0.004672897 0.007633588 0.008602152 0.005847953 0.003490401 
0.009208103 0.000000000 0.010389610 0.012358394 0.012358394 
0.012358394 0.012358394 0.012358394 0.012358394 0.012358394 
0.012358394 0.012358394 0.012358394 0.012358394 
0.000000000 0.000000000 0.000000000 0.003344482 0.006172840 
0.002336449 0.015267176 0.004301075 0.005847953 0.005235602 
0.005524862 0.010040160 0.010389610 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 
0.000000000 0.002793296 0.000000000 0.003344482 0.009259259 
0.007009346 0.007633588 0.004301075 0.009746589 0.008726004 
0.012891344 0.008032129 0.007792208 0.008238929 0.008238929 
0.008238929 0.008238929 0.008238929 0.008238929 0.008238929 
0.008238929 0.008238929 0.008238929 0.008238929 
0.000000000 0.000000000 0.002604167 0.006688963 0.003086420 
0.002336449 0.013358779 0.008602152 0.009746589 0.005235602 
0.003683241 0.002008032 0.007792208 0.008238929 0.008238929 
0.008238929 0.008238929 0.008238929 0.008238929 0.008238929 
0.008238929 0.008238929 0.008238929 0.008238929 
0.000000000 0.000000000 0.002604167 0.000000000 0.003086420 
0.000000000 0.003816794 0.000000000 0.003898635 0.001745201 
0.001841621 0.010040160 0.005194805 0.005149330 0.005149330 
0.005149330 0.005149330 0.005149330 0.005149330 0.005149330 
0.005149330 0.005149330 0.005149330 0.005149330 
0.000000000 0.000000000 0.013020832 0.060200669 0.074074075 
0.049065422 0.051526718 0.064516127 0.072124757 0.055846423 
0.066298343 0.054216865 0.109090909 0.084449023 0.084449023 
0.084449023 0.084449023 0.084449023 0.084449023 0.084449023 
0.084449023 0.084449023 0.084449023 0.084449023 
0.000000000 0.002793296 0.002604167 0.040133778 0.040123459 
0.049065422 0.022900762 0.019354839 0.046783622 0.040139619 
0.047882136 0.048192773 0.044155847 0.064881563 0.064881563 
0.064881563 0.064881563 0.064881563 0.064881563 0.064881563 
0.064881563 0.064881563 0.064881563 0.064881563 
0.000000000 0.000000000 0.002604167 0.023411371 0.018518519 
0.030373834 0.019083969 0.030107526 0.042884991 0.024432810 
0.025782689 0.022088354 0.057142857 0.058702368 0.058702368 
0.058702368 0.058702368 0.058702368 0.058702368 0.058702368 
0.058702368 0.058702368 0.058702368 0.058702368 
0.007751938 0.000000000 0.000000000 0.000000000 0.003086420 
0.030373834 0.022900762 0.019354839 0.023391811 0.031413611 
0.018416205 0.024096387 0.046753250 0.048403706 0.048403706 
0.048403706 0.048403706 0.048403706 0.048403706 0.048403706 
0.048403706 0.048403706 0.048403706 0.048403706 
0.000000000 0.000000000 0.000000000 0.000000000 0.009259259 
0.023364486 0.017175574 0.017204301 0.013645224 0.012216405 
0.016574586 0.022088354 0.018181818 0.032955717 0.032955717 
0.032955717 0.032955717 0.032955717 0.032955717 0.032955717 
0.032955717 0.032955717 0.032955717 0.032955717 
0.000000000 0.002793296 0.002604167 0.003344482 0.012345679 
0.028037384 0.028625954 0.021505374 0.013645224 0.010471204 
0.031307552 0.006024096 0.010389610 0.028836250 0.028836250 
0.028836250 0.028836250 0.028836250 0.028836250 0.028836250 
0.028836250 0.028836250 0.028836250 0.028836250 
0.000000000 0.000000000 0.000000000 0.003344482 0.003086420 
0.025700934 0.036259543 0.010752687 0.007797271 0.006980803 
0.012891344 0.024096387 0.018181818 0.016477859 0.016477859 
0.016477859 0.016477859 0.016477859 0.016477859 0.016477859 
0.016477859 0.016477859 0.016477859 0.016477859 
0.000000000 0.002793296 0.002604167 0.000000000 0.003086420 
0.000000000 0.022900762 0.010752687 0.009746589 0.005235602 
0.012891344 0.016064256 0.010389610 0.013388259 0.013388259 
0.013388259 0.013388259 0.013388259 0.013388259 0.013388259 
0.013388259 0.013388259 0.013388259 0.013388259 
0.000000000 0.002793296 0.000000000 0.000000000 0.006172840 
0.002336449 0.003816794 0.010752687 0.005847953 0.005235602 
0.005524862 0.006024096 0.002597403 0.021627188 0.021627188 
0.021627188 0.021627188 0.021627188 0.021627188 0.021627188 
0.021627188 0.021627188 0.021627188 0.021627188 
0.000000000 0.002793296 0.000000000 0.000000000 0.003086420 
0.000000000 0.007633588 0.002150538 0.001949318 0.010471204 
0.003683241 0.010040160 0.005194805 0.011328527 0.011328527 
0.011328527 0.011328527 0.011328527 0.011328527 0.011328527 
0.011328527 0.011328527 0.011328527 0.011328527 
0.000000000 0.002793296 0.000000000 0.003344482 0.003086420 
0.007009346 0.000000000 0.010752687 0.011695906 0.019197207 
0.003683241 0.002008032 0.005194805 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 
0.007751938 0.005586592 0.002604167 0.000000000 0.003086420 
0.002336449 0.000000000 0.006451613 0.009746589 0.015706806 
0.000000000 0.002008032 0.000000000 0.010298661 0.010298661 
0.010298661 0.010298661 0.010298661 0.010298661 0.010298661 
0.010298661 0.010298661 0.010298661 0.010298661 
0.007751938 0.013966480 0.002604167 0.003344482 0.000000000 
0.000000000 0.003816794 0.002150538 0.013645224 0.008726004 
0.001841621 0.000000000 0.002597403 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 0.007209063 
0.007209063 0.007209063 0.007209063 0.007209063 
0.031007752 0.011173184 0.002604167 0.000000000 0.003086420 
0.002336449 0.003816794 0.002150538 0.001949318 0.015706806 
0.016574586 0.014056224 0.000000000 0.015447992 0.015447992 
0.015447992 0.015447992 0.015447992 0.015447992 0.015447992 
0.015447992 0.015447992 0.015447992 0.015447992 
0.054263569 0.008379888 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.004301075 0.003898635 0.013961606 
0.018416205 0.026104417 0.000000000 0.019567456 0.019567456 
0.019567456 0.019567456 0.019567456 0.019567456 0.019567456 
0.019567456 0.019567456 0.019567456 0.019567456 
0.031007752 0.011173184 0.005208333 0.006688963 0.006172840 
0.000000000 0.000000000 0.006451613 0.007797271 0.038394414 
0.047882136 0.026104417 0.002597403 0.022657054 0.022657054 
0.022657054 0.022657054 0.022657054 0.022657054 0.022657054 
0.022657054 0.022657054 0.022657054 0.022657054 
0.023255814 0.027932961 0.018229168 0.006688963 0.006172840 
0.002336449 0.000000000 0.000000000 0.003898635 0.019197207 
0.009208103 0.032128513 0.007792208 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 
0.038759690 0.016759777 0.023437500 0.006688963 0.003086420 
0.000000000 0.000000000 0.004301075 0.000000000 0.001745201 
0.003683241 0.016064256 0.031168830 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 0.003089598 
0.003089598 0.003089598 0.003089598 0.003089598 
0.015503876 0.055865921 0.007812500 0.010033445 0.006172840 
0.004672897 0.003816794 0.000000000 0.000000000 0.003490401 
0.001841621 0.014056224 0.002597403 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 
0.046511628 0.036312848 0.015625000 0.006688963 0.006172840 
0.004672897 0.000000000 0.000000000 0.001949318 0.000000000 
0.003683241 0.000000000 0.005194805 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 0.009268795 
0.009268795 0.009268795 0.009268795 0.009268795 
0.046511628 0.039106146 0.015625000 0.020066891 0.012345679 
0.002336449 0.001908397 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.007792208 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 0.006179197 
0.006179197 0.006179197 0.006179197 0.006179197 
0.038759690 0.033519555 0.026041668 0.003344482 0.003086420 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.001841621 0.000000000 0.000000000 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 0.004119465 
0.004119465 0.004119465 0.004119465 0.004119465 
0.457364351 0.427374303 0.351562500 0.240802690 0.151234567 
0.088785045 0.064885497 0.070967741 0.040935673 0.022687608 
0.020257825 0.014056224 0.015584417 0.041194644 0.041194644 
0.041194644 0.041194644 0.041194644 0.041194644 0.041194644 
0.041194644 0.041194644 0.041194644 0.041194644 
0.015503876 0.025139665 0.028645832 0.006688963 0.015432099 
0.021028036 0.017175574 0.021505374 0.013645224 0.013961606 
0.020257825 0.026104417 0.012987013 0.017507724 0.017507724 
0.017507724 0.017507724 0.017507724 0.017507724 0.017507724 
0.017507724 0.017507724 0.017507724 0.017507724 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.111111000 0.026316000 0.032786999 0.023622001 0.051470999 
0.025478000 0.055000000 0.041958001 0.062857002 0.062068999 
0.042253502 0.022727270 0.042372879 0.042968750 0.042968750 
0.042968750 0.042968750 0.042968750 0.042968750 0.042968750 
0.042968750 0.042968750 0.042968750 0.042968750 
0.055555999 0.078947000 0.016393000 0.055117998 0.051470999 
0.019107999 0.055000000 0.055943999 0.045713998 0.048276000 
0.035211299 0.037878789 0.050847460 0.054687500 0.054687500 
0.054687500 0.054687500 0.054687500 0.054687500 0.054687500 
0.054687500 0.054687500 0.054687500 0.054687500 
0.166666999 0.052632000 0.032786999 0.055117998 0.051470999 
0.050955001 0.035000000 0.041958001 0.028571000 0.062068999 
0.042253502 0.045454551 0.033898309 0.046875000 0.046875000 
0.046875000 0.046875000 0.046875000 0.046875000 0.046875000 
0.046875000 0.046875000 0.046875000 0.046875000 
0.055555999 0.000000000 0.065573998 0.007874000 0.036765002 
0.025478000 0.039999999 0.041958001 0.051429000 0.027586000 
0.042253502 0.030303029 0.025423730 0.050781250 0.050781250 
0.050781250 0.050781250 0.050781250 0.050781250 0.050781250 
0.050781250 0.050781250 0.050781250 0.050781250 
0.000000000 0.026316000 0.032786999 0.062991999 0.022058999 
0.038217001 0.039999999 0.013986000 0.022856999 0.034483001 
0.042253502 0.015151520 0.008474580 0.031250000 0.031250000 
0.031250000 0.031250000 0.031250000 0.031250000 0.031250000 
0.031250000 0.031250000 0.031250000 0.031250000 
0.055555999 0.000000000 0.016393000 0.000000000 0.036765002 
0.006369000 0.025000000 0.034965001 0.011429000 0.020690000 
0.028169001 0.015151520 0.000000000 0.027343750 0.027343750 
0.027343750 0.027343750 0.027343750 0.027343750 0.027343750 
0.027343750 0.027343750 0.027343750 0.027343750 
0.000000000 0.052632000 0.016393000 0.007874000 0.014706000 
0.019107999 0.045000002 0.020979000 0.028571000 0.013793000 
0.035211299 0.030303029 0.033898309 0.023437500 0.023437500 
0.023437500 0.023437500 0.023437500 0.023437500 0.023437500 
0.023437500 0.023437500 0.023437500 0.023437500 
0.000000000 0.000000000 0.016393000 0.015748000 0.029412000 
0.019107999 0.035000000 0.006993000 0.028571000 0.041379001 
0.028169001 0.007575760 0.016949151 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.032786999 0.007874000 0.022058999 
0.031847000 0.015000000 0.006993000 0.017143000 0.034483001 
0.028169001 0.030303029 0.016949151 0.015625000 0.015625000 
0.015625000 0.015625000 0.015625000 0.015625000 0.015625000 
0.015625000 0.015625000 0.015625000 0.015625000 
0.000000000 0.000000000 0.000000000 0.007874000 0.000000000 
0.006369000 0.015000000 0.013986000 0.022856999 0.006897000 
0.014084500 0.015151520 0.016949151 0.011718750 0.011718750 
0.011718750 0.011718750 0.011718750 0.011718750 0.011718750 
0.011718750 0.011718750 0.011718750 0.011718750 
0.000000000 0.000000000 0.000000000 0.007874000 0.000000000 
0.006369000 0.035000000 0.027972000 0.000000000 0.013793000 
0.007042300 0.007575760 0.016949151 0.019531250 0.019531250 
0.019531250 0.019531250 0.019531250 0.019531250 0.019531250 
0.019531250 0.019531250 0.019531250 0.019531250 
0.000000000 0.000000000 0.000000000 0.023622001 0.014706000 
0.025478000 0.015000000 0.013986000 0.011429000 0.000000000 
0.007042300 0.000000000 0.033898309 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.007874000 0.014706000 
0.012739000 0.000000000 0.027972000 0.005714000 0.006897000 
0.021126799 0.007575760 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.055555999 0.000000000 0.000000000 0.007874000 0.022058999 
0.012739000 0.015000000 0.000000000 0.000000000 0.000000000 
0.014084500 0.045454551 0.008474580 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.014706000 
0.000000000 0.015000000 0.006993000 0.017143000 0.000000000 
0.000000000 0.030303029 0.008474580 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.015748000 0.000000000 
0.000000000 0.005000000 0.006993000 0.011429000 0.020690000 
0.000000000 0.007575760 0.000000000 0.015625000 0.015625000 
0.015625000 0.015625000 0.015625000 0.015625000 0.015625000 
0.015625000 0.015625000 0.015625000 0.015625000 
0.000000000 0.000000000 0.016393000 0.023622001 0.007353000 
0.025478000 0.015000000 0.013986000 0.005714000 0.013793000 
0.007042300 0.030303029 0.016949151 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.016393000 0.000000000 0.014706000 
0.006369000 0.005000000 0.013986000 0.005714000 0.013793000 
0.007042300 0.007575760 0.000000000 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 
0.000000000 0.000000000 0.016393000 0.007874000 0.000000000 
0.012739000 0.010000000 0.006993000 0.034286000 0.000000000 
0.028169001 0.007575760 0.016949151 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.007874000 0.007353000 
0.006369000 0.015000000 0.006993000 0.011429000 0.006897000 
0.014084500 0.007575760 0.008474580 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.006369000 0.010000000 0.000000000 0.011429000 0.013793000 
0.000000000 0.015151520 0.000000000 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 
0.000000000 0.000000000 0.000000000 0.023622001 0.000000000 
0.012739000 0.010000000 0.013986000 0.000000000 0.000000000 
0.007042300 0.030303029 0.016949151 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.015748000 0.000000000 
0.012739000 0.000000000 0.006993000 0.005714000 0.006897000 
0.014084500 0.007575760 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.006369000 0.000000000 0.000000000 0.011429000 0.020690000 
0.014084500 0.007575760 0.008474580 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 
0.000000000 0.000000000 0.032786999 0.000000000 0.000000000 
0.006369000 0.015000000 0.000000000 0.005714000 0.000000000 
0.021126799 0.000000000 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.000000000 0.007353000 
0.000000000 0.005000000 0.000000000 0.011429000 0.006897000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.016393000 0.015748000 0.014706000 
0.012739000 0.005000000 0.013986000 0.005714000 0.000000000 
0.007042300 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.007874000 0.000000000 
0.006369000 0.005000000 0.013986000 0.005714000 0.006897000 
0.014084500 0.000000000 0.008474580 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.006369000 0.000000000 0.013986000 0.005714000 0.006897000 
0.000000000 0.000000000 0.000000000 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 
0.000000000 0.000000000 0.000000000 0.000000000 0.007353000 
0.025478000 0.010000000 0.013986000 0.000000000 0.000000000 
0.007042300 0.000000000 0.008474580 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.007874000 0.022058999 
0.044585999 0.000000000 0.000000000 0.011429000 0.006897000 
0.021126799 0.015151520 0.016949151 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 
0.000000000 0.000000000 0.016393000 0.000000000 0.036765002 
0.000000000 0.005000000 0.020979000 0.017143000 0.006897000 
0.007042300 0.007575760 0.008474580 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.016393000 0.015748000 0.007353000 
0.006369000 0.005000000 0.020979000 0.011429000 0.006897000 
0.000000000 0.000000000 0.008474580 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.006369000 0.025000000 0.013986000 0.000000000 0.027586000 
0.007042300 0.000000000 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.015748000 0.029412000 
0.012739000 0.005000000 0.000000000 0.000000000 0.006897000 
0.042253502 0.022727270 0.000000000 0.011718750 0.011718750 
0.011718750 0.011718750 0.011718750 0.011718750 0.011718750 
0.011718750 0.011718750 0.011718750 0.011718750 
0.000000000 0.000000000 0.016393000 0.000000000 0.000000000 
0.006369000 0.000000000 0.013986000 0.017143000 0.020690000 
0.014084500 0.022727270 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.020000000 0.013986000 0.000000000 0.006897000 
0.000000000 0.015151520 0.025423730 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.007874000 0.000000000 
0.000000000 0.015000000 0.013986000 0.005714000 0.006897000 
0.028169001 0.007575760 0.016949151 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.016393000 0.000000000 0.000000000 
0.019107999 0.000000000 0.013986000 0.011429000 0.027586000 
0.000000000 0.000000000 0.000000000 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 
0.000000000 0.000000000 0.000000000 0.007874000 0.007353000 
0.012739000 0.000000000 0.013986000 0.005714000 0.006897000 
0.000000000 0.022727270 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.000000000 0.022058999 
0.012739000 0.000000000 0.006993000 0.017143000 0.006897000 
0.000000000 0.007575760 0.008474580 0.015625000 0.015625000 
0.015625000 0.015625000 0.015625000 0.015625000 0.015625000 
0.015625000 0.015625000 0.015625000 0.015625000 
0.000000000 0.000000000 0.000000000 0.000000000 0.007353000 
0.006369000 0.020000000 0.013986000 0.000000000 0.013793000 
0.021126799 0.015151520 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.000000000 0.007353000 
0.000000000 0.005000000 0.000000000 0.017143000 0.006897000 
0.000000000 0.000000000 0.025423730 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.016393000 0.007874000 0.000000000 
0.000000000 0.010000000 0.000000000 0.005714000 0.013793000 
0.021126799 0.000000000 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.000000000 0.007874000 0.007353000 
0.006369000 0.005000000 0.013986000 0.000000000 0.000000000 
0.000000000 0.015151520 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.032786999 0.031496000 0.044117998 
0.089171998 0.039999999 0.062936999 0.079999998 0.041379001 
0.091549300 0.090909094 0.093220338 0.089843750 0.089843750 
0.089843750 0.089843750 0.089843750 0.089843750 0.089843750 
0.089843750 0.089843750 0.089843750 0.089843750 
0.000000000 0.000000000 0.000000000 0.023622001 0.007353000 
0.019107999 0.035000000 0.048951000 0.045713998 0.048276000 
0.042253502 0.068181820 0.118644074 0.054687500 0.054687500 
0.054687500 0.054687500 0.054687500 0.054687500 0.054687500 
0.054687500 0.054687500 0.054687500 0.054687500 
0.000000000 0.000000000 0.000000000 0.007874000 0.007353000 
0.025478000 0.025000000 0.013986000 0.039999999 0.041379001 
0.028169001 0.030303029 0.059322029 0.054687500 0.054687500 
0.054687500 0.054687500 0.054687500 0.054687500 0.054687500 
0.054687500 0.054687500 0.054687500 0.054687500 
0.000000000 0.000000000 0.000000000 0.000000000 0.022058999 
0.000000000 0.025000000 0.034965001 0.022856999 0.034483001 
0.056338001 0.030303029 0.016949151 0.062500000 0.062500000 
0.062500000 0.062500000 0.062500000 0.062500000 0.062500000 
0.062500000 0.062500000 0.062500000 0.062500000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.006369000 0.010000000 0.020979000 0.000000000 0.013793000 
0.000000000 0.000000000 0.050847460 0.050781250 0.050781250 
0.050781250 0.050781250 0.050781250 0.050781250 0.050781250 
0.050781250 0.050781250 0.050781250 0.050781250 
0.000000000 0.000000000 0.000000000 0.015748000 0.000000000 
0.012739000 0.005000000 0.006993000 0.028571000 0.027586000 
0.021126799 0.015151520 0.016949151 0.027343750 0.027343750 
0.027343750 0.027343750 0.027343750 0.027343750 0.027343750 
0.027343750 0.027343750 0.027343750 0.027343750 
0.000000000 0.000000000 0.000000000 0.000000000 0.007353000 
0.000000000 0.000000000 0.006993000 0.000000000 0.006897000 
0.021126799 0.015151520 0.033898309 0.031250000 0.031250000 
0.031250000 0.031250000 0.031250000 0.031250000 0.031250000 
0.031250000 0.031250000 0.031250000 0.031250000 
0.000000000 0.026316000 0.000000000 0.000000000 0.000000000 
0.000000000 0.005000000 0.006993000 0.011429000 0.013793000 
0.014084500 0.015151520 0.016949151 0.046875000 0.046875000 
0.046875000 0.046875000 0.046875000 0.046875000 0.046875000 
0.046875000 0.046875000 0.046875000 0.046875000 
0.000000000 0.026316000 0.000000000 0.000000000 0.000000000 
0.006369000 0.010000000 0.006993000 0.005714000 0.000000000 
0.007042300 0.045454551 0.008474580 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.055555999 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.006993000 0.000000000 0.000000000 
0.000000000 0.030303029 0.000000000 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 
0.055555999 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.015625000 0.015625000 
0.015625000 0.015625000 0.015625000 0.015625000 0.015625000 
0.015625000 0.015625000 0.015625000 0.015625000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.015151520 0.008474580 0.023437500 0.023437500 
0.023437500 0.023437500 0.023437500 0.023437500 0.023437500 
0.023437500 0.023437500 0.023437500 0.023437500 
0.055555999 0.026316000 0.016393000 0.015748000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.026316000 0.000000000 0.007874000 0.000000000 
0.000000000 0.000000000 0.000000000 0.011429000 0.006897000 
0.014084500 0.000000000 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.055555999 0.026316000 0.000000000 0.007874000 0.014706000 
0.000000000 0.005000000 0.000000000 0.005714000 0.006897000 
0.007042300 0.000000000 0.025423730 0.019531250 0.019531250 
0.019531250 0.019531250 0.019531250 0.019531250 0.019531250 
0.019531250 0.019531250 0.019531250 0.019531250 
0.055555999 0.052632000 0.016393000 0.015748000 0.007353000 
0.000000000 0.000000000 0.000000000 0.000000000 0.006897000 
0.000000000 0.007575760 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.000000000 0.049180001 0.023622001 0.007353000 
0.006369000 0.005000000 0.000000000 0.005714000 0.000000000 
0.000000000 0.007575760 0.008474580 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.026316000 0.016393000 0.007874000 0.007353000 
0.006369000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.007575760 0.000000000 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 
0.000000000 0.000000000 0.016393000 0.031496000 0.007353000 
0.012739000 0.005000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 0.007812500 
0.007812500 0.007812500 0.007812500 0.007812500 
0.000000000 0.052632000 0.032786999 0.000000000 0.000000000 
0.006369000 0.000000000 0.000000000 0.000000000 0.006897000 
0.000000000 0.000000000 0.008474580 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.007874000 0.000000000 
0.000000000 0.005000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 0.003906250 
0.003906250 0.003906250 0.003906250 0.003906250 
0.000000000 0.026316000 0.032786999 0.007874000 0.014706000 
0.000000000 0.000000000 0.006993000 0.005714000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.222222000 0.421052992 0.344262004 0.275590986 0.264705986 
0.203822002 0.144999996 0.125873998 0.097143002 0.075861998 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.052632000 0.000000000 0.039370000 0.000000000 
0.025478000 0.015000000 0.006993000 0.034286000 0.013793000 
0.007042300 0.007575760 0.025423730 0.011718750 0.011718750 
0.011718750 0.011718750 0.011718750 0.011718750 0.011718750 
0.011718750 0.011718750 0.011718750 0.011718750 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000 0.000000000 
0.000000000 0.000000000 0.000000000 0.000000000
